pub struct CachedStateProvider<S> { /* private fields */ }Expand description
A wrapper of a state provider and a shared cache.
CacheFillMode controls whether misses populate the shared cache. This is used by background
prewarmers and speculative execution workers that intentionally seed the cache for other
readers. Canonical execution usually leaves this disabled because the EVM database State
already caches reads during the block, and the shared cache is updated after the block from the
final [BundleState]. See also ExecutionCache::insert_state.
Execution-cache and txpool-snapshot hit/miss metrics are recorded separately when
CachedStateMetrics is provided. Slow-block CacheStats are controlled separately by
Self::new_with_mode.
Implementations
Sourceimpl<S> CachedStateProvider<S>
impl<S> CachedStateProvider<S>
Sourcepub const fn new(
state_provider: S,
caches: ExecutionCache,
metrics: Option<CachedStateMetrics>,
) -> Self
pub const fn new( state_provider: S, caches: ExecutionCache, metrics: Option<CachedStateMetrics>, ) -> Self
Creates a new CachedStateProvider from an ExecutionCache, state provider, and
optional CachedStateMetrics.
Sourcepub const fn new_prewarm(state_provider: S, caches: ExecutionCache) -> Self
pub const fn new_prewarm(state_provider: S, caches: ExecutionCache) -> Self
Creates a cache-filling CachedStateProvider.
Doesn’t accept metrics because prewarming path does not need to report hit/misses.
Sourcepub const fn new_with_mode(
state_provider: S,
caches: ExecutionCache,
fill_mode: CacheFillMode,
metrics: Option<CachedStateMetrics>,
cache_stats: Option<Arc<CacheStats>>,
) -> Self
pub const fn new_with_mode( state_provider: S, caches: ExecutionCache, fill_mode: CacheFillMode, metrics: Option<CachedStateMetrics>, cache_stats: Option<Arc<CacheStats>>, ) -> Self
Creates a CachedStateProvider with explicit cache fill behavior and optional
block-local cache stats.
Sourcepub fn with_txpool_snapshot(
self,
snapshot: Option<TxPoolPrewarmCacheSnapshot>,
) -> Self
pub fn with_txpool_snapshot( self, snapshot: Option<TxPoolPrewarmCacheSnapshot>, ) -> Self
Adds an immutable txpool-prewarm snapshot as the first cache lookup tier.